@@ -26,7 +26,6 @@
 #include "connect.h"
 #include "extconf.h"
 
-#if HAVE_TYPE_VIRNWFILTERPTR
 static VALUE c_nwfilter;
 
 static void nwfilter_free(void *n)
@@ -48,7 +47,7 @@ VALUE ruby_libvirt_nwfilter_new(virNWFilterPtr n, VALUE conn)
  * call-seq:
  *   nwfilter.undefine -> nil
  *
- * Call virNWFilterUndefine[http://www.libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterUndefine]
+ * Call virNWFilterUndefine[https://libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterUndefine]
  * to undefine the network filter.
  */
 static VALUE libvirt_nwfilter_undefine(VALUE n)
@@ -62,7 +61,7 @@ static VALUE libvirt_nwfilter_undefine(VALUE n)
  * call-seq:
  *   nwfilter.name -> String
  *
- * Call virNWFilterGetName[http://www.libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterGetName]
+ * Call virNWFilterGetName[https://libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterGetName]
  * to retrieve the network filter name.
  */
 static VALUE libvirt_nwfilter_name(VALUE n)
@@ -76,7 +75,7 @@ static VALUE libvirt_nwfilter_name(VALUE n)
  * call-seq:
  *   nwfilter.uuid -> String
  *
- * Call virNWFilterGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterGetUUIDString]
+ * Call virNWFilterGetUUIDString[https://libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterGetUUIDString]
  * to retrieve the network filter UUID.
  */
 static VALUE libvirt_nwfilter_uuid(VALUE n)
@@ -89,7 +88,7 @@ static VALUE libvirt_nwfilter_uuid(VALUE n)
  * call-seq:
  *   nwfilter.xml_desc(flags=0) -> String
  *
- * Call virNWFilterGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterGetXMLDesc]
+ * Call virNWFilterGetXMLDesc[https://libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterGetXMLDesc]
  * to retrieve the XML for this network filter.
  */
 static VALUE libvirt_nwfilter_xml_desc(int argc, VALUE *argv, VALUE n)
@@ -108,7 +107,7 @@ static VALUE libvirt_nwfilter_xml_desc(int argc, VALUE *argv, VALUE n)
  * call-seq:
  *   nwfilter.free -> nil
  *
- * Call virNWFilterFree[http://www.libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterFree]
+ * Call virNWFilterFree[https://libvirt.org/html/libvirt-libvirt-nwfilter.html#virNWFilterFree]
  * to free this network filter.  After this call the network filter object is
  * no longer valid.
  */
@@ -117,15 +116,15 @@ static VALUE libvirt_nwfilter_free(VALUE n)
     ruby_libvirt_generate_call_free(NWFilter, n);
 }
 
-#endif
 
 /*
  * Class Libvirt::NWFilter
  */
 void ruby_libvirt_nwfilter_init(void)
 {
-#if HAVE_TYPE_VIRNWFILTERPTR
     c_nwfilter = rb_define_class_under(m_libvirt, "NWFilter", rb_cObject);
+    rb_undef_alloc_func(c_nwfilter);
+
     rb_define_attr(c_nwfilter, "connection", 1, 0);
 
     /* NWFilter object methods */
@@ -134,5 +133,4 @@ void ruby_libvirt_nwfilter_init(void)
     rb_define_method(c_nwfilter, "uuid", libvirt_nwfilter_uuid, 0);
     rb_define_method(c_nwfilter, "xml_desc", libvirt_nwfilter_xml_desc, -1);
     rb_define_method(c_nwfilter, "free", libvirt_nwfilter_free, 0);
-#endif
 }
